@@ -28,11 +28,11 @@ __license__   = "LGPL"
 
 # $ORCA_MAJOR_VERSION.$ORCA_MINOR_VERSION.$ORCA_MICRO_VERSION
 #
-version     = "3.1.2-xdesktop"
+version     = "3.1.3-xdesktop"
 
 # "--prefix" parameter used when configuring the build.
 #
-prefix      = "/home/jd/orca/bld"
+prefix      = "/home/jd/orca-for-release/bld"
 
 # The package name (should be "orca").
 #
